/**
 * This source code is licensed under the MIT-style license found in the
 * LICENSE file in the root directory of this source tree. *
 *
 * @providesModule toHaveStyle
 * @flow
 */

import negateMessage from '../negateMessage';
import type { Matcher } from '../types/Matcher';
import type { MatcherMethods } from '../types/MatcherMethods';
import type { EnzymeObject } from '../types/EnzymeObject';

export default {
  toHaveStyle(util:Object, customEqualityTesters:Object) : MatcherMethods {
    function toHaveStyle(enzymeWrapper:EnzymeObject, styleKey:string, styleValue:?any) : Matcher {
      const style = enzymeWrapper.prop('style');

      // error if component doesnt have style
      if (!style) {
        return {
          pass: false,
          message: 'Expected component to have a style prop',
        };
      }

      // error if the style key doesnt exist
      if (!style.hasOwnProperty(styleKey)) {
        return {
          pass: false,
          message: `Expected component to have style key of "${styleKey}"`,
        };
      }

      return {
        pass: util.equals(style[styleKey], styleValue, customEqualityTesters),
        message: `
          Expected component style values to match for key "${styleKey}":
          Actual: ${style[styleKey]}
          Expected: ${styleValue}
        `,
      };
    }
    return {
      compare(enzymeWrapper:EnzymeObject, styleKey:string, styleValue:?any) : Matcher {
        return toHaveStyle(enzymeWrapper, styleKey, styleValue);
      },

      negativeCompare(enzymeWrapper:EnzymeObject, styleKey:string, styleValue:?any) : Matcher {
        const result:Matcher = toHaveStyle(enzymeWrapper, styleKey, styleValue);

        result.message = negateMessage(result.message);
        result.pass = !result.pass;

        return result;
      },
    };
  },
};
